@@ -75,6 +75,18 @@ class AppHandler(object):
     def get_title(self, default=None):
         return self.config.app_title(default=default)
 
+    def get_timezone(self, key='default'):
+        from rattail.time import timezone
+        return timezone(self.config, key)
+
+    def localtime(self, *args, **kwargs):
+        from rattail.time import localtime
+        return localtime(self.config, *args, **kwargs)
+
+    def make_utc(self, *args, **kwargs):
+        from rattail.time import make_utc
+        return make_utc(*args, **kwargs)
+
     def load_entry_points(self, group, **kwargs):
         return load_entry_points(group, **kwargs)
 
@@ -210,15 +222,31 @@ class AppHandler(object):
 
         :returns: List of all registered Import/Export Handler classes.
         """
-        handlers = self.load_entry_points('rattail.importing',
+        # first load all "registered" Handler classes
+        Handlers = self.load_entry_points('rattail.importing',
                                           ignore_errors=ignore_errors)
-        handlers = list(handlers.values())
+
+        # organize registered classes by spec
+        specs = {}
+        for Handler in six.itervalues(Handlers):
+            spec = '{}:{}'.format(Handler.__module__, Handler.__name__)
+            specs[spec] = Handler
+
+        # many handlers may not be registered per se, but may be
+        # designated via config.  so try to include those too
+        for Handler in six.itervalues(Handlers):
+            spec = self.get_designated_import_handler_spec(Handler.get_key())
+            if spec and spec not in specs:
+                specs[spec] = load_object(spec)
+
+        # flatten back to simple list
+        Handlers = list(specs.values())
 
         if sort:
-            handlers.sort(key=lambda h: (h.get_generic_host_title(),
+            Handlers.sort(key=lambda h: (h.get_generic_host_title(),
                                          h.get_generic_local_title()))
 
-        return handlers
+        return Handlers
 
     def get_designated_import_handlers(self, with_alternates=False, **kwargs):
         """
@@ -495,6 +523,24 @@ class AppHandler(object):
         """
         return pretty_quantity(value, **kwargs)
 
+    def render_cases_units(self, cases, units):
+        """
+        Render a human-friendly string showing the given number of
+        cases and/or units.
+        """
+        if cases is not None:
+            label = "case" if abs(cases) == 1 else "cases"
+            cases = "{} {}".format(self.render_quantity(cases), label)
+
+        if units is not None:
+            label = "unit" if abs(units) == 1 else "units"
+            units = "{} {}".format(self.render_quantity(units), label)
+
+        if cases and units:
+            return "{} + {}".format(cases, units)
+
+        return cases or units
+
     def render_date(self, value, **kwargs):
         """
         Must return a human-friendly display string for the given ``date``
