@@ -375,7 +375,7 @@ class BatchHandler(object):
         should *not* override the :meth:`~do_populate()` method, but callers
         *should* use that one directly.
         """
-        raise NotImplementedError("Please implement `{}.populate()` method".format(batch.__class__.__name__))
+        raise NotImplementedError("Please implement `{}.populate()` method".format(self.__class__.__name__))
 
     def refreshable(self, batch):
         """
