@@ -254,15 +254,9 @@ class LabelBatchHandler(BatchHandler):
                 row.status_code = row.STATUS_PRODUCT_NOT_FOUND
                 return
 
+        self.refresh_product_basics(row)
+
         product = row.product
-        row.item_id = product.item_id
-        row.upc = product.upc
-        row.brand_name = six.text_type(product.brand or '')
-        row.description = product.description
-        row.size = product.size
-        department = product.department
-        row.department_number = department.number if department else None
-        row.department_name = department.name if department else None
         category = product.category
         row.category_code = category.code if category else None
         row.category_name = category.name if category else None
