@@ -246,7 +246,7 @@ class DataSync(Subcommand):
 
             # seconds since last run
             self.collectd_putval(plugin, 'gauge-{}_watcher_seconds_since_lastrun'.format(key),
-                                 (now - lastrun).seconds, now=now)
+                                 now.timestamp() - lastrun.timestamp(), now=now)
 
         # now inspect the change queue..
 
