@@ -449,8 +449,9 @@ class ImportVersions(ImportRattail):
         return kwargs
 
     def run(self, args):
-        if not self.config.versioning_enabled():
-            self.stderr.write("Continuum versioning is not enabled, per config\n")
+        if not self.config.versioning_has_been_enabled:
+            self.stderr.write("Continuum versioning is not enabled, "
+                              "per config and/or command line args\n")
             sys.exit(1)
         super(ImportVersions, self).run(args)
 
