@@ -118,7 +118,7 @@ class RattailConfig(object):
         else: # PY2
             self.parser = configparser.SafeConfigParser()
         for path in files:
-            self.read_file(path, require=True)
+            self.read_file(path)
         self.usedb = usedb
         if self.usedb is None:
             self.usedb = self.getbool('rattail.config', 'usedb', usedb=False, default=False)
@@ -142,6 +142,9 @@ class RattailConfig(object):
             else:
                 self._session_factory = lambda: (Session(), True)
 
+        # this is always false, unless/until it becomes true
+        self.versioning_has_been_enabled = False
+
     def read_file(self, path, recurse=True, require=False):
         """
         Read in config from the given file.
