@@ -47,6 +47,8 @@ class DataSyncConsumer(object):
         self.runas_username = runas
         self.watcher = watcher
         self.model = config.get_model()
+        self.enum = config.get_enum()
+        self.app = config.get_app()
 
     def setup(self):
         """
