@@ -282,6 +282,17 @@ class CustomerOrderItemBase(object):
     Full price (not including tax etc.) which the customer is asked to pay for the item.
     """)
 
+    price_needs_confirmation = sa.Column(sa.Boolean(), nullable=True, doc="""
+    Flag indicating that the price for this item should be confirmed
+    by someone, before the order advances to the procurement phase.
+
+    Items/rows with this flag set will probably indicate that also via
+    their status.
+
+    When the price is eventually confirmed by someone, this flag
+    should be cleared and probably the status will update as well.
+    """)
+
     paid_amount = sa.Column(sa.Numeric(precision=8, scale=3), nullable=False, default=0, doc="""
     Amount which the customer has paid toward the :attr:`total_price` of theitem.
     """)
@@ -322,6 +333,18 @@ class CustomerOrderItem(CustomerOrderItemBase, Base):
 
     status_code = sa.Column(sa.Integer(), nullable=False)
 
+    status_text = sa.Column(sa.String(length=255), nullable=True, doc="""
+    Text which may briefly explain the batch status code, if needed.
+    """)
+
+    def add_event(self, type_code, user, **kwargs):
+        """
+        Convenience method to add an event for the order item.
+        """
+        self.events.append(CustomerOrderItemEvent(type_code=type_code,
+                                                  user=user,
+                                                  **kwargs))
+
 
 class CustomerOrderItemEvent(Base):
     """
