@@ -78,7 +78,7 @@ class TestCommand(TestCase):
     def test_run_with_no_args_prints_help(self):
         command = core.Command()
         with patch.object(command, 'print_help') as print_help:
-            command.run()
+            self.assertRaises(SystemExit, command.run)
             print_help.assert_called_once_with()
 
     def test_run_with_single_help_arg_prints_help(self):
@@ -102,7 +102,7 @@ class TestCommand(TestCase):
     def test_run_with_unknown_subcommand_arg_prints_help(self):
         command = core.Command()
         with patch.object(command, 'print_help') as print_help:
-            command.run('invalid-command-name')
+            self.assertRaises(SystemExit, command.run, 'invalid-command-name')
             print_help.assert_called_once_with()
 
     def test_stdout_may_be_redirected(self):
