@@ -31,6 +31,7 @@ import sys
 import datetime
 import decimal
 import subprocess
+import logging
 
 import six
 from pkg_resources import iter_entry_points
@@ -41,6 +42,8 @@ except ImportError: # pragma no cover
     from ordereddict import OrderedDict
 
 
+log = logging.getLogger(__name__)
+
 # generic singleton to indicate an arg which isn't set etc.
 NOTSET = object()
 
@@ -94,6 +97,14 @@ def import_module_path(module_path):
 
     :returns: The referenced module.
     """
+    if six.PY3:
+        try:
+            import importlib
+        except ImportError:
+            pass
+        else:
+            return importlib.import_module(module_path)
+
     if module_path in sys.modules:
         return sys.modules[module_path]
     module = __import__(module_path)
@@ -144,7 +155,7 @@ def load_object(specifier):
     return getattr(module, name)
 
 
-def load_entry_points(group):
+def load_entry_points(group, ignore_errors=False):
     """
     Load a set of ``setuptools``-style entry points.
 
@@ -157,7 +168,15 @@ def load_entry_points(group):
     """
     entry_points = {}
     for entry_point in iter_entry_points(group):
-        entry_points[entry_point.name] = entry_point.load()
+        try:
+            ep = entry_point.load()
+        except:
+            if not ignore_errors:
+                raise
+            log.warning("failed to load entry point: %s", entry_point,
+                        exc_info=True)
+        else:
+            entry_points[entry_point.name] = ep
     return entry_points
 
 
